FlutterShazamKitPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterShazamKitPlatform
Implementers

Constructors

FlutterShazamKitPlatform()
Constructs a FlutterShazamKitPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
onDetectStateChangedCallback ↔ OnDetectStateChanged?
getter/setter pair
onErrorCallback ↔ OnError?
getter/setter pair
onMatchResultDiscoveredCallback ↔ OnMatchResultDiscovered?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureShazamKitSession({String? developerToken}) → Future
endDetectionWithMicrophone() → Future
endSession() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDetectStateChanged(OnDetectStateChanged onDetectStateChanged) → void
onError(OnError onError) → void
onMatchResultDiscovered(OnMatchResultDiscovered onMatchResultDiscovered) → void
startDetectionWithMicrophone() → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterShazamKitPlatform
getter/setter pair